Summary:       Provides a framework to help other GNU packages produce multi-lingual messages.
Name:          gettext
Version:       0.22
Release:       5%{?dist}
License:       GPLv3+ and LGPLv2+ and GFDL
URL:           https://www.gnu.org/software/gettext/
Source0:       https://ftp.gnu.org/pub/gnu/gettext/%{name}-%{version}.tar.gz

BuildRequires: make automake libtool gcc-c++ xz
BuildRequires: emacs libxml2-devel libacl-devel libunistring-devel
Requires:      %{name}-runtime = %{version}-%{release}
Provides:      bundled(gnulib)
Provides:      bundled(libcroco) = 0.6.13

%description
The GNU gettext package offers to programmers, translators, and even users,
a well integrated set of tools and documentation. Specifically,
the GNU gettext utilities are a set of tools that provides a framework
to help other GNU packages produce multi-lingual messages.
These tools include a set of conventions about how programs should be written
to support message catalogs, a directory and file naming organization for the message catalogs themselves,
a runtime library supporting the retrieval of translated messages,
and a few stand-alone programs to massage in various ways the sets of translatable strings,
or already translated strings.


%package common-devel
Summary:   Common development files for %{name}
License:   GPLv3+
BuildArch: noarch

%description common-devel
This package contains common architecture independent gettext development files.


%package devel
Summary:  Development files for %{name}
License:  LGPLv2+ and GPLv3+ and GFDL
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}
Requires: %{name}-common-devel = %{version}-%{release}
Requires: xz diffutils
Provides: gettext-autopoint = %{version}-%{release}

%description devel
This package contains all development related files necessary for
developing or compiling applications/libraries that needs
internationalization capability. You also need this package if you
want to add gettext support for your project.


%package libs
Summary:   Libraries for %{name}
License:   LGPLv2+ and GPLv3+
Obsoletes: libtextstyle

%description libs
This package contains libraries used internationalization support.


%package -n emacs-%{name}
Summary:   Support for editing po files within GNU Emacs
BuildArch: noarch
Provides:  emacs-po-mode
Requires:  emacs(bin) >= %{_emacs_version}
Provides:  emacs-%{name}-el = %{version}-%{release}

%description -n emacs-%{name}
This package provides a major mode for editing po files within GNU Emacs.

%package runtime
Summary: GNU runtime libraries and programs for producing multi-lingual messages
License: GPLv3+ and LGPLv2+
# Depend on the exact version of the library sub package
Requires: %{name}-libs = %{version}-%{release}
Requires: %{name}-envsubst = %{version}-%{release}
Conflicts: %{name} < %{version}-%{release}


%description runtime
The GNU gettext-runtime package provides an easy to use runtime libraries and
programs for creating, using, and modifying natural language catalogs
and is a powerful and simple method for internationalizing programs.

%package envsubst
Summary: Substitutes the values of environment variables
Conflicts: %{name} < %{version}-%{release}

%description envsubst
Substitutes the values of environment variables.

%prep
%autosetup -p2

sed -e 's/\(gl_cv_libxml_force_included=\)yes/\1no/' \
    -i libtextstyle/configure


%build
# prevent "without -Wformat" error when building libtextstyle
export CFLAGS="$RPM_OPT_FLAGS -Wformat"

export CPPFLAGS="-I%{_includedir}/libxml2"
export LIBS="-lxml2"
%configure --without-included-gettext --enable-nls --disable-static \
    --enable-shared --disable-csharp --disable-rpath \
    --disable-java --disable-native-java \
    --with-xz

sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|CC=.g..|& -Wl,--as-needed|' \
    -i $(find . -name libtool)

%make_build


%install
%make_install \
    lispdir=%{_datadir}/emacs/site-lisp/gettext \
    aclocaldir=%{_datadir}/aclocal EXAMPLESFILES=""

chmod 755 ${RPM_BUILD_ROOT}%{_libdir}/preloadable_libintl.so
rm ${RPM_BUILD_ROOT}%{_libdir}/lib*.la
rm ${RPM_BUILD_ROOT}%{_libdir}/libgettext{src,lib}.so
rm -f ${RPM_BUILD_ROOT}%{_includedir}/textstyle.h  ${RPM_BUILD_ROOT}%{_includedir}/textstyle/*.h

rm -f ${RPM_BUILD_ROOT}%{_infodir}/dir
rm -f ${RPM_BUILD_ROOT}%{_infodir}/libtextstyle*

for i in gettext-runtime/man/*.html; do
  rm ${RPM_BUILD_ROOT}%{_datadir}/doc/gettext/`basename $i`
done
rm -r ${RPM_BUILD_ROOT}%{_datadir}/doc/gettext/javadoc*
rm -rf ${RPM_BUILD_ROOT}%{_datadir}/doc/gettext/examples

rm -rf htmldoc
mkdir htmldoc
mv ${RPM_BUILD_ROOT}%{_datadir}/doc/gettext/* ${RPM_BUILD_ROOT}%{_datadir}/doc/libasprintf/* htmldoc
rm -r ${RPM_BUILD_ROOT}%{_datadir}/doc/libasprintf
rm -r ${RPM_BUILD_ROOT}%{_datadir}/doc/gettext
rm -rf ${RPM_BUILD_ROOT}%{_datadir}/doc/libtextstyle

rm -f ${RPM_BUILD_ROOT}%{_datadir}/%{name}/libintl.jar
rm -f ${RPM_BUILD_ROOT}%{_datadir}/%{name}/gettext.jar

mkdir -p $RPM_BUILD_ROOT%{_datadir}/%{name}/its

install -d ${RPM_BUILD_ROOT}%{_emacs_sitestartdir}
mv ${RPM_BUILD_ROOT}%{_emacs_sitelispdir}/%{name}/start-po.el ${RPM_BUILD_ROOT}%{_emacs_sitestartdir}
rm ${RPM_BUILD_ROOT}%{_emacs_sitelispdir}/%{name}/start-po.elc

%find_lang %{name}-runtime
%find_lang %{name}-tools


%check
export LD_LIBRARY_PATH=$RPM_BUILD_ROOT%{_libdir}:$PWD/gettext-tools/intl/.libs
make check LIBUNISTRING=-lunistring

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%files -f %{name}-tools.lang
%license COPYING
%doc README AUTHORS NEWS THANKS gettext-runtime/BUGS gettext-tools/misc/DISCLAIM
%doc gettext-runtime/man/*.1.html gettext-runtime/intl/COPYING*
%{_bindir}/*
%{_infodir}/gettext*
%exclude %{_mandir}/man1/autopoint.1*
%exclude %{_mandir}/man1/gettextize.1*
%exclude %{_mandir}/man1/msghack.1*
%{_mandir}/man1/*
%{_libdir}/%{name}
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/its
%{_datadir}/%{name}/ABOUT-NLS
%{_datadir}/%{name}/po
%{_datadir}/%{name}/styles
%dir %{_datadir}/%{name}-%{version}
%{_datadir}/%{name}-%{version}/its

%files common-devel
%{_datadir}/%{name}/archive.*.tar.xz

%files devel
%doc gettext-runtime/man/*.3.html ChangeLog
%{_bindir}/autopoint
%{_bindir}/gettextize
%{_datadir}/%{name}/projects/
%{_datadir}/%{name}/config.rpath
%{_datadir}/%{name}/*.h
%{_datadir}/%{name}/msgunfmt.tcl
%{_datadir}/aclocal/*
%{_includedir}/autosprintf.h
%{_includedir}/gettext-po.h
%{_infodir}/autosprintf*
%{_libdir}/libasprintf.so
%{_libdir}/libgettextpo.so
%{_libdir}/preloadable_libintl.so
%{_mandir}/man1/autopoint.1*
%{_mandir}/man1/gettextize.1*
%{_mandir}/man3/*
%{_datadir}/%{name}/javaversion.class
%doc gettext-runtime/intl-java/javadoc*

%files libs
%{_libdir}/libasprintf.so.0*
%{_libdir}/libgettextpo.so.0*
%{_libdir}/libgettextlib-0.*.so
%{_libdir}/libgettextsrc-0.*.so
%{_libdir}/libtextstyle.so*

%files -n emacs-%{name}
%dir %{_emacs_sitelispdir}/%{name}
%{_emacs_sitelispdir}/%{name}/*.elc
%{_emacs_sitelispdir}/%{name}/*.el
%{_emacs_sitestartdir}/*.el

%files runtime -f %{name}-runtime.lang
%license COPYING
%doc gettext-runtime/BUGS
%doc gettext-runtime/man/gettext.1.html
%doc gettext-runtime/man/ngettext.1.html
%doc gettext-runtime/intl/COPYING*
%{_bindir}/gettext
%{_bindir}/gettext.sh
%{_bindir}/ngettext
%{_mandir}/man1/*

%files envsubst
%license COPYING
%doc gettext-runtime/man/envsubst.1.html
%{_bindir}/envsubst
%{_mandir}/man1/envsubst.1*

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.22-5
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.22-4
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.22-3
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Aug 17 2023 Shuo Wang <abushwang@tencent.com> - 0.22-2
- Rebuilt for libunistring 1.1

* Wed Jul 26 2023 kianli <kianli@tencent.com> - 0.22-1
- Upgrade to 0.22

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.21.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.21.1-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Nov 7 2022 Shuo Wang <abushwang@tencent.com> - 0.21.1-1
- Initial build

* Mon Apr 18 2022 rockerzhu <rockerzhu@tencent.com> - 0.21-1
- Initial build
